Crate iceoryx2_pal_testing

Crate iceoryx2_pal_testing 

Low-level testing utilities and helpers.

These utilities may only leverage the platform abstraction iceoryx2_pal_posix in their implementation. The std module may be used in std builds, however a no_std equivalent must be included for all usages.

Modules

assert
lifetime_tracker
memory
watchdog

Macros

assert_that
test_fail
test_requires

Constants

AT_LEAST_TIMING_VARIANCE